--
-- Selected TOC Entries:
--
--
-- TOC Entry ID 2 (OID 1960992)
--
-- Name: subflow Type: TABLE Owner: aliphe
--

CREATE TABLE subflow (
	object_id integer NOT NULL,
	flow_id integer NOT NULL,
	container_id integer NOT NULL,
	floworder smallint NOT NULL,
	flowdirection character varying(10) NOT NULL,
	flowmethod character varying(20),
	dependant character varying(10) DEFAULT 'no',
	direct character varying(10) DEFAULT 'no',
	onoutgoerr character varying(20),
	keepalive character varying(10) DEFAULT 'no',
	mailonerr character varying(10) DEFAULT 'yes',
	mailonsucc character varying(10) DEFAULT 'no',
	Constraint subflow_pkey Primary Key (object_id)
);

--
-- TOC Entry ID 3 (OID 1960992)
--
-- Name: subflow_ukey1 Type: INDEX Owner: aliphe
--

CREATE UNIQUE INDEX subflow_ukey1 on subflow using btree ( container_id int4_ops, flow_id int4_ops, flowdirection varchar_ops, floworder int2_ops );

